@@ -5,7 +5,8 @@ from .cloud_front import (
     CloudfrontDistributionResponseHeadersPolicy,
     CloudfrontResponseHeaderConfigLongHstsMaxAge,
 )
-from .code_build import CodeBuildProjectCloudWatchLogs
+from .code_build import CodeBuildProjectCloudWatchLogs, CodeBuildProjectImage
+from .ecr import EcrRepositoryAutocleanupTag
 from .ecs import (
     EcsServiceDeploymentConfiguration,
     EcsServiceFargatePlatformVersionNotOutdated,
@@ -21,6 +22,8 @@ __all__ = [
     "CloudfrontDistributionResponseHeadersPolicy",
     "CloudfrontResponseHeaderConfigLongHstsMaxAge",
     "CodeBuildProjectCloudWatchLogs",
+    "CodeBuildProjectImage",
+    "EcrRepositoryAutocleanupTag",
     "EcsServiceDeploymentConfiguration",
     "EcsServiceFargatePlatformVersionNotOutdated",
     "IntrinsicFunctionSubUnresolvedObject",
